@@ -77,6 +77,7 @@ class SheinReturnOrder(Base):
     return_reason_type = Column(Integer, nullable=True, comment='退货原因类型')
     return_reason_type_name = Column(String(100), nullable=True, comment='退货原因类型名称')
     return_reason = Column(Text, nullable=True, comment='退货原因')
+    reject_pic_url_list = Column(JSON, nullable=True, comment='拒绝图片URL列表')
 
     # 商品信息
     skc_name_list = Column(JSON, nullable=True, comment='SKC名称列表')
@@ -123,6 +124,10 @@ class SheinReturnOrder(Base):
     # 用户备注字段（供后续web界面使用）
     user_notes = Column(Text, nullable=True, comment='用户备注')
 
+    return_factotry_status = Column(Integer, nullable=True, comment='退回工厂状态,1已退回,2未退回')
+    return_factotry_by = Column(String(50), nullable=True, comment='退回工厂操作人')
+    financial_settlement_status = Column(Integer, nullable=True, comment='财务结算状态,1已结算,2未结算')
+
     # 定义索引
     __table_args__ = (
         Index('ix_return_order_no', 'return_order_no'),
@@ -310,6 +315,7 @@ class SheinReturnOrderManager:
             return_reason_type=data.get('returnReasonType'),
             return_reason_type_name=data.get('returnReasonTypeName'),
             return_reason=data.get('returnReason'),
+            reject_pic_url_list=data.get('rejectPicUrlList'),
             skc_name_list=data.get('skcNameList'),
             supplier_code_list=data.get('supplierCodeList'),
             goods_thumb=data.get('goodsThumb'),
@@ -379,6 +385,7 @@ class SheinReturnOrderManager:
         existing_order.return_reason_type = data.get('returnReasonType')
         existing_order.return_reason_type_name = data.get('returnReasonTypeName')
         existing_order.return_reason = data.get('returnReason')
+        existing_order.reject_pic_url_list = data.get('rejectPicUrlList')
         existing_order.skc_name_list = data.get('skcNameList')
         existing_order.supplier_code_list = data.get('supplierCodeList')
         existing_order.goods_thumb = data.get('goodsThumb')
