@@ -5,7 +5,7 @@
 import os
 import platform
 import shutil
-import time
+import time, datetime
 import traceback
 import uuid
 import json
@@ -74,7 +74,7 @@ class ZiniaoClient:
         """启动客户端"""
         try:
             if self.is_windows:
-                cmd = [self.client_path, '--run_type=web_driver', '--ipc_type=http', '--port=' + str(self.socket_port)]
+                cmd = [self.client_path, '--run_type=web_driver', '--show_sidb=true', '--ipc_type=http', '--port=' + str(self.socket_port)]
             elif self.is_mac:
                 cmd = ['open', '-a', self.client_path, '--args', '--run_type=web_driver', '--ipc_type=http',
                        '--port=' + str(self.socket_port)]
@@ -258,7 +258,7 @@ class ZiniaoBrowser:
         """打开启动页面并执行业务逻辑"""
         page = browser_context.pages[0]
         page.goto(launcher_page)
-        page.wait_for_load_state('load')
+        page.wait_for_timeout(3000)
 
         run_func(page, store_username, store_name, task_key)
 
@@ -272,21 +272,91 @@ class ZiniaoTaskManager:
         self.browser = browser
         self.config = config
 
+    def daily_cleanup_superbrowser(self, browser_id):
+        """
+        每天删除一次SuperBrowser缓存文件夹
+
+        Args:
+            browser_id (str): 浏览器ID，如 '26986387919128'
+        """
+
+        # 获取本地AppData路径
+        local_appdata = os.getenv('LOCALAPPDATA')
+        if not local_appdata:
+            log("错误: 无法获取LOCALAPPDATA路径")
+            return False
+
+        # 构建路径
+        cache_path = os.path.join(local_appdata, 'SuperBrowser')
+        target_folder = os.path.join(cache_path, f'User Data\\Chromium_{browser_id}')
+        flag_file = os.path.join(cache_path, f'User Data\\cleanup_flag_{browser_id}.txt')
+
+        # 检查目标文件夹是否存在
+        if not os.path.exists(target_folder):
+            log(f"目标文件夹不存在: {target_folder}")
+            return False
+
+        # 获取当前日期
+        today = datetime.date.today()
+        today_str = today.strftime('%Y-%m-%d')
+
+        # 检查标志文件
+        need_cleanup = True
+
+        if os.path.exists(flag_file):
+            try:
+                # 读取标志文件中的日期
+                with open(flag_file, 'r', encoding='utf-8') as f:
+                    last_cleanup_date = f.read().strip()
+
+                # 如果是今天已经清理过，则跳过
+                if last_cleanup_date == today_str:
+                    log(f"今天({today_str})已经清理过，跳过删除操作")
+                    need_cleanup = False
+
+            except Exception as e:
+                log(f"读取标志文件时出错: {e}")
+                # 如果读取出错，继续执行清理
+
+        if need_cleanup:
+            try:
+                # 删除目标文件夹
+                log(f"正在删除文件夹: {target_folder}")
+                shutil.rmtree(target_folder)
+                log("删除成功!")
+
+                # 创建/更新标志文件
+                os.makedirs(os.path.dirname(flag_file), exist_ok=True)
+                with open(flag_file, 'w', encoding='utf-8') as f:
+                    f.write(today_str)
+
+                log(f"已创建标志文件: {flag_file}")
+                return True
+
+            except Exception as e:
+                log(f"删除文件夹时出错: {e}")
+                return False
+
+        return True
+
     def run_single_store_task(self, browser_info: Dict[str, Any],
             run_func: Callable, task_key: str,
             just_store_username: Optional[List[str]] = None,
             is_skip_store: Optional[Callable] = None
     ):
         """运行单个店铺的任务"""
+        store_id = browser_info.get('browserOauth')
+        store_name = browser_info.get("browserName")
+        store_username = browser_info.get("store_username")
+
+        # 删除浏览器缓存,一天一删
+        browser_id = browser_info.get("browserId")
+        self.daily_cleanup_superbrowser(browser_id)
+
         retry_count = 0
         while True:
             try:
                 retry_count += 1
-
-                store_id = browser_info.get('browserOauth')
-                store_name = browser_info.get("browserName")
-                store_username = browser_info.get("store_username")
-
                 # 记录店铺账号与店铺别名对应关系
                 cache_file = f'{self.config.auto_dir}/shein_store_alias.json'
                 write_dict_to_file_ex(cache_file, {store_username: store_name}, [store_username])
@@ -349,7 +419,7 @@ class ZiniaoTaskManager:
                         self.browser.close_store(store_id)
                     break
             except:
-                send_exception(f'第{retry_count}次运行失败，准备重新打开店铺')
+                send_exception(f'第{retry_count}次运行失败，准备重新打开店铺: {store_username},{store_name},{store_id}')
                 if retry_count > 5:
                     break
 
